<?php
/**
 * Wayfarer Theme Customizer
 */

// Loads custom control
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/custom-text.php';

// Loads the customizer settings
require trailingslashit( get_template_directory() ) . 'inc/customizer/featured-posts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/promo.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/posts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/about.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/instagram.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/misc.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/colors.php';

/**
 * Custom customizer functions.
 */
function wayfarer_customize_functions( $wp_customize ) {

	// Register new panel: Design
	$wp_customize->add_panel( 'wayfarer_design', array(
		'title'       => esc_html__( 'Design', 'wayfarer' ),
		'description' => esc_html__( 'This panel is used for customizing the design of your site.', 'wayfarer' ),
		'priority'    => 125,
	) );

	// Register new panel: Theme Options
	$wp_customize->add_panel( 'wayfarer_options', array(
		'title'       => esc_html__( 'Theme Options', 'wayfarer' ),
		'description' => esc_html__( 'This panel is used for customizing the Wayfarer theme.', 'wayfarer' ),
		'priority'    => 130,
	) );

	// Live preview of Site Title
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

	// Enable selective refresh to the Site Title
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'            => '.site-title a',
			'settings'         => array( 'blogname' ),
			'render_callback'  => function() {
				return get_bloginfo( 'name', 'display' );
			}
		) );
	}

	// Move the Colors section.
	$wp_customize->get_section( 'colors' )->panel    = 'wayfarer_design';
	$wp_customize->get_section( 'colors' )->priority = 1;

	// Move the Background Image section.
	$wp_customize->get_section( 'background_image' )->panel    = 'wayfarer_design';
	$wp_customize->get_section( 'background_image' )->priority = 7;

	// Move the Static Front Page section.
	$wp_customize->get_section( 'static_front_page' )->panel    = 'wayfarer_design';
	$wp_customize->get_section( 'static_front_page' )->priority = 9;

	// Move the Additional CSS section.
	$wp_customize->get_section( 'custom_css' )->panel    = 'wayfarer_design';
	$wp_customize->get_section( 'custom_css' )->priority = 11;

	// Move background color to background image section.
	$wp_customize->get_section( 'background_image' )->title = esc_html__( 'Background', 'wayfarer' );
	$wp_customize->get_control( 'background_color' )->section = 'background_image';

}
add_action( 'customize_register', 'wayfarer_customize_functions', 99 );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function wayfarer_customize_preview_js() {
	wp_enqueue_script( 'wayfarer-customizer', get_template_directory_uri() . '/assets/js/customizer/customizer.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'wayfarer_customize_preview_js' );

/**
 * Custom styles.
 */
function wayfarer_custom_css() {

	// Set up empty variable.
	$css = '';

	// Get the customizer value.
	$color = get_theme_mod( 'wayfarer-accent-colors', '#ffcc00' );

	if ( $color != '#ffcc00' ) {
		$css .= '
		.slides-pagination a.current,
		.understroke:after,
		.upperstroke:before,
		.accent-box,
		.mobile-nav .dropdown-menu,
		.mobile-nav .search-field,
		.btn:hover,
		a.more_notes_link:hover,
		a.btn-cta:hover,
		a.btn-cta:focus,
		.comment-respond input.button:hover,
		.widget_tag_cloud a:hover {
			background-color: ' . sanitize_hex_color( $color ) . ';
		}

		.text-accent,
		.text-accent a,
		a.text-accent,
		.text-dark.widget-disqus a,
		.text-dark.widget-disqus a:focus,
		.text-dark.widget-disqus a:hover,
		.text-dark.widget-notes a,
		.text-dark.widget-notes a:focus,
		.text-dark.widget-notes a:hover,
		.text-light.widget-disqus a,
		.text-light.widget-disqus a:focus,
		.text-light.widget-disqus a:hover,
		.text-light.widget-notes a,
		.text-light.widget-notes a:focus,
		.text-light.widget-notes a:hover,
		.menu-toggle-open,
		a.btn-cta,
		.comment-respond input.button,
		.accent-box,
		.mobile-nav .dropdown-menu,
		.mobile-nav .search-field,
		.btn:hover,
		a.more_notes_link:hover,
		.nav-links .nav > a:hover,
		.nav-links .nav > a:focus,
		.pagination-links a,
		a.btn-cta:hover,
		a.btn-cta:focus {
			color: ' . sanitize_hex_color( $color ) . ';
		}

		.slide-frame,
		.frame:after,
		.sidebar .photo_link:hover:after,
		.site-footer .muted-hover-frame:hover:after,
		.mobile-nav-wrapper,
		a.btn-cta,
		.comment-respond input.button,
		.widget li a,
		.post-text a,
		.widget-tags-list a,
		.nav-links .nav > a:hover,
		.nav-links .nav > a:focus,
		.widget_tag_cloud a:hover {
			border-color: ' . sanitize_hex_color( $color ) . ';
		}
		';
	}

	// Print the custom style
	wp_add_inline_style( 'wayfarer-style', $css );

}
add_action( 'wp_enqueue_scripts', 'wayfarer_custom_css' );

/**
 * Display theme documentation on customizer page.
 */
function wayfarer_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'wayfarer-doc', get_template_directory_uri() . '/assets/js/customizer/doc.js', array(), '1.0.0', true );

	// Localize the script
	wp_localize_script( 'wayfarer-doc', 'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/wayfarer/' ),
			'prefixLabel' => esc_html__( 'Documentation', 'wayfarer' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'wayfarer_documentation_link' );

/**
 * Custom RSS feed url.
 */
function wayfarer_custom_rss_url( $output, $feed ) {

	// Get the custom rss feed url
	$url = get_theme_mod( 'wayfarer-custom-rss' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( ! empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
add_filter( 'feed_link', 'wayfarer_custom_rss_url', 10, 2 );

/**
 * Retrieve tags list.
 */
function wayfarer_tags_list() {

	// Set up empty array.
	$tags = array();

	// Retrieve available tags.
	$tags_obj = get_tags();

	// Set default/empty tag.
	$tags[''] = esc_html__( 'Select a tag &hellip;', 'wayfarer' );

	// Display the tags.
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_attr( $tag->name );
	}

	return $tags;

}

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean (true|false).
 */
function wayfarer_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize the Footer Credits
 */
function wayfarer_sanitize_textarea( $text ) {
	if ( current_user_can( 'unfiltered_html' ) ) {
		$text = $text;
	} else {
		$text = wp_kses_post( $text );
	}
	return $text;
}

/**
 * Sanitize the featured posts order value.
 */
function wayfarer_sanitize_featured_orderby( $order ) {
	if ( ! in_array( $order, array( 'date', 'rand' ) ) ) {
		$order = 'date';
	}
	return $order;
}
